@@ -3,7 +3,7 @@ package OpenGuides::Feed;
 use strict;
 
 use vars qw( $VERSION );
-$VERSION = '0.01';
+$VERSION = '0.02';
 
 use Wiki::Toolkit::Feed::Atom;
 use Wiki::Toolkit::Feed::RSS;
@@ -11,6 +11,11 @@ use Time::Piece;
 use URI::Escape;
 use Carp 'croak';
 
+use base qw( Class::Accessor );
+# Add more here if we need them - this one added for testing purposes.
+my @variables = qw( html_equiv_link );
+OpenGuides::Feed->mk_accessors( @variables );
+
 sub new {
     my ($class, @args) = @_;
     my $self = {};
@@ -52,18 +57,23 @@ sub _init {
     $self->{default_country}  = $config->default_country   || "";
     $self->{site_description} = $config->site_desc         || "";
     $self->{og_version}       = $args{og_version};
-    $self->{html_equiv_link}  = $self->{config}->script_url . '?action=rc';
+    $self->{html_equiv_link}  = $self->{config}->script_url
+                                . $self->{config}->script_name . '?action=rc';
 
     $self;
 }
 
+=over 4
+
 =item B<set_feed_name_and_url_params>
 Overrides the default feed name and default feed http equivalent url.
 Useful on custom feeds, where the defaults are incorrect.
 
    $feed->set_feed_name_and_url("Search Results", "search=pub");
    $feed->build_mini_feed_for_nodes("rss", @search_results);
+
 =cut
+
 sub set_feed_name_and_url_params {
     my ($self, $name, $url) = @_;
 
@@ -79,6 +89,7 @@ sub set_feed_name_and_url_params {
 }
 
 =item B<make_feed>
+
 Produce one of the standard feeds, in the requested format.
 
 
@@ -88,7 +99,9 @@ my $feed_contents = feeds->make_feed(
                     );
 
 Passes additional arguments through to the underlying Wiki::Toolkit::Feed
+
 =cut
+
 sub make_feed {
     my ($self, %args) = @_;
     
@@ -127,18 +140,23 @@ sub make_feed {
 }
 
 =item B<build_feed_for_nodes>
+
 For the given feed type, build a feed from the supplied list of nodes.
 Will figure out the feed timestamp from the newest node, and output a
  last modified header based on this.
 
 my @nodes = $wiki->fetch_me_nodes_I_like();
 my $feed_contents = $feed->build_feed_for_nodes("rss", @nodes);
+
 =cut
+
 sub build_feed_for_nodes {
     my ($self, $format, @nodes) = @_;
     return $self->render_feed_for_nodes($format, undef, 1, @nodes);
 }
+
 =item B<build_mini_feed_for_nodes>
+
 For the given feed type, build a mini feed (name and distance) from the 
  supplied list of nodes.
 Will figure out the feed timestamp from the newest node, and output a
@@ -146,16 +164,21 @@ Will figure out the feed timestamp from the newest node, and output a
 
 my @nodes = $wiki->search_near_here();
 my $feed_contents = $feed->build_mini_feed_for_nodes("rss", @nodes);
+
 =cut
+
 sub build_mini_feed_for_nodes {
     my ($self, $format, @nodes) = @_;
     return $self->render_feed_for_nodes($format, undef, 0, @nodes);
 }
 
 =item B<render_feed_for_nodes>
+
 Normally internal method to perform the appropriate building of a feed
- based on a list of nodes.
+based on a list of nodes.
+
 =cut
+
 sub render_feed_for_nodes {
     my ($self, $format, $html_url, $is_full, @nodes) = @_;
 
@@ -188,10 +211,13 @@ sub render_feed_for_nodes {
 }
 
 =item B<default_content_type>
+
 For the given feed type, return the default content type for that feed.
 
 my $content_type = $feed->default_content_type("rss");
+
 =cut
+
 sub default_content_type {
     my ($self,$feed_type) = @_;
 
@@ -211,6 +237,7 @@ sub default_content_type {
 }
 
 =item B<fetch_maker>
+
 For the given feed type, identify and return the maker routine for feeds
 of that type. 
 
@@ -218,7 +245,9 @@ my $maker = $feed->fetch_maker("rss");
 my $feed_contents = maker->node_all_versions(%options);
 
 Will always return something of type Wiki::Toolkit::Feed::Listing
+
 =cut
+
 sub fetch_maker {
     my ($self,$feed_type) = @_;
 
@@ -285,6 +314,8 @@ sub feed_timestamp {
     $self->rss_maker->rss_timestamp(%args);
 }
 
+=back
+
 =head1 NAME
 
 OpenGuides::Feed - generate data feeds for OpenGuides in various formats.
@@ -401,7 +432,7 @@ The OpenGuides Project (openguides-dev@lists.openguides.org)
 
 =head1 COPYRIGHT
 
-Copyright (C) 2003-2006 The OpenGuides Project.  All Rights Reserved.
+Copyright (C) 2003-2009 The OpenGuides Project.  All Rights Reserved.
 
 This module is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
