@@ -2,7 +2,7 @@ package OpenGuides::Utils;
 
 use strict;
 use vars qw( $VERSION );
-$VERSION = '0.11';
+$VERSION = '0.12';
 
 use Carp qw( croak );
 use Wiki::Toolkit;
@@ -10,6 +10,9 @@ use Wiki::Toolkit::Formatter::UseMod;
 use Wiki::Toolkit::Plugin::RSS::Reader;
 use URI::Escape;
 use MIME::Lite;
+use Net::Netmask;
+use List::Util qw( first );
+use Data::Validate::URI qw( is_web_uri );
 
 =head1 NAME
 
@@ -208,7 +211,13 @@ sub make_wiki_object {
                         $url = $1;
                     }
 
-                    my $rss = Wiki::Toolkit::Plugin::RSS::Reader->new(url => $url);
+                    # We can't do much about remote errors fetching
+                    # at this stage
+                    my $rss = eval { Wiki::Toolkit::Plugin::RSS::Reader->new(url => $url); };
+                    if ( $@ ) {
+                        warn $@;
+                        return '';
+                    }
                     my @items = $rss->retrieve;
 
                     # Ten items only at this till.
@@ -376,7 +385,6 @@ sub validate_edit {
     return \@fails if @fails;
 
     # Now do our real validation
-    # Numeric tests
     foreach my $var (qw(os_x os_y)) {
         if ($q->param($var) and $q->param($var) !~ /^-?\d+$/) {
             push @fails, "$var must be integer, was: " . $q->param($var);
@@ -389,6 +397,12 @@ sub validate_edit {
         }
     }
 
+    if ( $q->param('website') and $q->param('website') ne 'http://' ) {
+        unless ( is_web_uri( $q->param('website') ) ) {
+            push @fails, $q->param('website') . ' is not a valid web URI';
+        }
+    }
+
     return \@fails;
 
 };
@@ -491,6 +505,35 @@ sub send_email {
     }
 }
 
+=item B<in_moderate_whitelist>
+
+ if (OpenGuides::Utils->in_moderate_whitelist( '127.0.0.1' )) {
+     # skip moderation and apply new verson to published site
+ }
+
+Admins can supply a comma separated list of IP addresses or CIDR-notation
+subnets indicating the hosts which can bypass enforced moderation. Any
+values which cannot be parsed by C<NetAddr::IP> will be ignored.
+
+=cut
+
+sub in_moderate_whitelist {
+    my ($self, $config, $ip) = @_;
+    return undef if not defined $ip;
+
+    # create NetAddr::IP object of the test IP
+    my $addr = Net::Netmask->new2($ip) or return undef;
+
+    # load the configured whitelist
+    my @whitelist
+        = split ',', $config->moderate_whitelist;
+
+    # test each entry in the whitelist
+    return eval{
+        first { Net::Netmask->new2($_)->match($addr->base) } @whitelist
+    };
+}
+
 =back
 
 =head1 AUTHOR
